@@ -45,6 +45,7 @@
 #include <ctype.h>
 
 #include "kipmsgwidget.h"
+#include "hideconfigdialog.h"
 #include "senddialog.h"
 #include "recievedialog.h"
 #include "kipmsgconfig.h"
@@ -195,10 +196,12 @@ kipmsgWidget::kipmsgWidget(QWidget* parent, const char* name, WFlags fl)
 		IpMsgAgent->AddBroadcastAddress( broadcastAddress.data() );
 	}
 
-//TODO IPv6
 	IpMsgAgent->setUseIPv6( true );
+
 	IpMsgAgent->StartNetwork( NetworkConfig::getSpecifyNics() );
 
+	HideConfigDialog::SetupHideHosts();
+
     MainPopup = new KPopupMenu(this);
 	DraftsPopup = new KPopupMenu(this);
 	AbsencePopup = new KPopupMenu(this);
